@@ -1,45 +1,20 @@
-// Copyright (C) 1999-2001 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ccAudio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of ccaudio.
-//
-// The exception is that, if you link the ccaudio library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the ccaudio library code into it.
-//
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the
-// name ccaudio.  If you copy code from other releases into a copy of
-// ccaudio, as the General Public License permits, the exception does
-// not apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own for ccaudio, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.
-//
-// Based on freely licensed g72x codec code from Sun Microsystems, Inc.
-
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "codecs.h"
 
@@ -266,11 +241,12 @@ static void update(
 		/* UPA1 */
 		/* update predictor pole a[0] */
 		state_ptr->a[0] -= state_ptr->a[0] >> 8;
-		if (dqsez != 0)
+		if (dqsez != 0) {
 			if (pks1 == 0)
 				state_ptr->a[0] += 192;
 			else
 				state_ptr->a[0] -= 192;
+		}
 
 		/* LIMD */
 		a1ul = 15360 - a2p;
@@ -533,7 +509,7 @@ g723_3Codec::g723_3Codec() : AudioCodec()
 	info.framecount = 8;
 	info.bitrate = 24000;
 	info.encoding = g723_3bit;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 	info.rate = 8000;
 	memset(&encode_state, 0, sizeof(encode_state));
 	memset(&decode_state, 0, sizeof(decode_state));
@@ -551,7 +527,7 @@ g723_3Codec::g723_3Codec(const char *id, Encoding e) : AudioCodec(id, e)
 	info.framecount = 8;
 	info.bitrate = 24000;
 	info.rate = 8000;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 }
 
 g723_3Codec::~g723_3Codec()
@@ -672,7 +648,7 @@ g723_2Codec::g723_2Codec() : AudioCodec()
 	info.framecount = 4;
 	info.bitrate = 16000;
 	info.encoding = g723_3bit;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 	info.rate = 8000;
 	memset(&encode_state, 0, sizeof(encode_state));
 	memset(&decode_state, 0, sizeof(decode_state));
@@ -690,7 +666,7 @@ g723_2Codec::g723_2Codec(const char *id, Encoding e) : AudioCodec(id, e)
 	info.framecount = 4;
 	info.bitrate = 16000;
 	info.rate = 8000;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 }
 
 g723_2Codec::~g723_2Codec()
@@ -820,7 +796,7 @@ g723_5Codec::g723_5Codec() : AudioCodec()
 	info.framecount = 8;
 	info.bitrate = 40000;
 	info.encoding = g723_5bit;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 	info.rate = 8000;
 	memset(&encode_state, 0, sizeof(encode_state));
 	memset(&decode_state, 0, sizeof(decode_state));
@@ -838,7 +814,7 @@ g723_5Codec::g723_5Codec(const char *id, Encoding e) : AudioCodec(id, e)
 	info.framecount = 8;
 	info.bitrate = 40000;
 	info.rate = 8000;
-	info.annotation = "g.723";
+	info.annotation = (char *)"g.723";
 }
 
 g723_5Codec::~g723_5Codec()
@@ -964,7 +940,7 @@ g721Codec::g721Codec() : AudioCodec()
 	info.framecount = 2;
 	info.rate = 8000;
 	info.bitrate = 32000;
-	info.annotation = "g.721";
+	info.annotation = (char *)"g.721";
 	info.encoding = g721ADPCM;
 
 	memset(&encode_state, 0, sizeof(encode_state));
@@ -983,7 +959,7 @@ g721Codec::g721Codec(const char *id, Encoding e) : AudioCodec(id, e)
 	info.framecount = 2;
 	info.rate = 8000;
 	info.bitrate = 32000;
-	info.annotation = "g.721";
+	info.annotation = (char *)"g.721";
 }
 
 g721Codec::~g721Codec()
