@@ -1,50 +1,27 @@
-// Copyright (C) 1999-2001 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ccAudio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception to the GNU General Public License, permission is
-// granted for additional uses of the text contained in its release
-// of ccaudio.
-//
-// The exception is that, if you link the ccaudio library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the ccaudio library code into it.
-//
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the
-// name ccaudio.  If you copy code from other releases into a copy of
-// ccaudio, as the General Public License permits, the exception does
-// not apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own for ccaudio, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "codecs.h"
 
 namespace ccAudioCodec {
 using namespace ost;
 
-static class g711u : public AudioCodec
-{
+static class g711u : public AudioCodec {
 public:
 	g711u();
 
@@ -55,8 +32,7 @@ public:
 
 } g711u;
 
-static class g711a : public AudioCodec
-{
+static class g711a : public AudioCodec {
 public:
 	g711a();
 
@@ -79,7 +55,7 @@ g711u::g711u() : AudioCodec("g.711", mulawAudio)
 	info.framecount = 1;
 	info.rate = 8000;
 	info.bitrate = 64000;
-	info.annotation = "mu-law";
+	info.annotation = (char *)"mu-law";
 }
 
 g711a::g711a() : AudioCodec("g.711", alawAudio)
@@ -88,12 +64,12 @@ g711a::g711a() : AudioCodec("g.711", alawAudio)
 	info.framecount = 1;
 	info.bitrate = 64000;
 	info.rate = 8000;
-	info.annotation = "a-law";
+	info.annotation = (char *)"a-law";
 }
 
 static unsigned ullevels[128] =
 {
-			32124,   31100,   30076,   29052,   28028, 
+			32124,   31100,   30076,   29052,   28028,
 	27004,   25980,   24956,   23932,   22908,   21884,   20860,
 	19836,   18812,   17788,   16764,   15996,   15484,   14972,
 	14460,   13948,   13436,   12924,   12412,   11900,   11388,
@@ -141,8 +117,7 @@ Audio::Level g711u::getPeak(void *data, unsigned samples)
 
 	unsigned char *dp = (unsigned char *)data;
 
-	while(samples--)
-	{
+	while(samples--) {
 		value = ullevels[*(dp++) & 0x7f];
 		if(value > max)
 			max = value;
@@ -153,22 +128,22 @@ Audio::Level g711u::getPeak(void *data, unsigned samples)
 unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
 {
 	static int ulaw[256] = {
-        0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,
-        4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
-        5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
-        5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
-        6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-        6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-        6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-        6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
-        7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7};
+		0,0,1,1,2,2,2,2,3,3,3,3,3,3,3,3,
+		4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,
+		5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
+		5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,
+		7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7};
 
 	register Sample sample;
 	int sign, exponent, mantissa, retval;
@@ -177,17 +152,16 @@ unsigned g711u::encode(Linear buffer, void *dest, unsigned lsamples)
 
 	count = lsamples;
 
-	while(lsamples--)
-	{
+	while(lsamples--) {
 		sample = *(buffer++);
 		        sign = (sample >> 8) & 0x80;
 	        if(sign != 0) sample = -sample;
-        	sample += 0x84;
-        	exponent = ulaw[(sample >> 7) & 0xff];
-        	mantissa = (sample >> (exponent + 3)) & 0x0f;
-        	retval = ~(sign | (exponent << 4) | mantissa);
-        	if(!retval)
-                	retval = 0x02;
+			sample += 0x84;
+			exponent = ulaw[(sample >> 7) & 0xff];
+			mantissa = (sample >> (exponent + 3)) & 0x0f;
+			retval = ~(sign | (exponent << 4) | mantissa);
+			if(!retval)
+			retval = 0x02;
 		*(d++) = (unsigned char)retval;
 	}
 	return count;
@@ -255,13 +229,11 @@ unsigned g711a::encode(Linear buffer, void *dest, unsigned lsamples)
 
 	count = lsamples;
 
-	while(lsamples--)
-	{
+	while(lsamples--) {
 		pcm_val = *(buffer++);
 		if(pcm_val >= 0)
 			mask = AMI_MASK | 0x80;
-		else
-		{
+		else {
 			mask = AMI_MASK;
 			pcm_val = -pcm_val;
 		}
@@ -305,12 +277,12 @@ Audio::Level g711a::getImpulse(void *data, unsigned samples)
 
 
 
-        unsigned char *dp = (unsigned char *)data;
+	unsigned char *dp = (unsigned char *)data;
 
-        while(samples--)
-                sum += (allevels[*(dp++) & 0x7f]);
+	while(samples--)
+		sum += (allevels[*(dp++) & 0x7f]);
 
-        return (Level)(sum / count);
+	return (Level)(sum / count);
 }
 
 Audio::Level g711a::getPeak(void *data, unsigned samples)
@@ -323,8 +295,7 @@ Audio::Level g711a::getPeak(void *data, unsigned samples)
 
 	unsigned char *dp = (unsigned char *)data;
 
-	while(samples--)
-	{
+	while(samples--) {
 		value = allevels[*(dp++) & 0x7f];
 		if(value > max)
 			max = value;
