@@ -1,39 +1,20 @@
 // Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ccAudio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
-//
-// This exception applies only to the code released under the name GNU
-// ccAudio.  If you copy code from other releases into a copy of GNU
-// ccAudio, as the General Public License permits, the exception does
-// not apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own for GNU ccAudio, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.
+// GNU Lesser General Public License for more details.
 //
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "private.h"
 #include "audio2.h"
@@ -62,6 +43,10 @@
 #define	RLL_SUFFIX ".rll"
 #endif
 
+#ifndef	RLL_SUFFIX
+#define	RLL_SUFFIX ".so"
+#endif
+
 static ccAudio_Mutex_ lock;
 
 #if defined(HAVE_PTHREAD_H)
@@ -184,11 +169,9 @@ bool AudioCodec::load(const char *name)
 {
 	char path[256];
 
-#ifdef	RLL_SUFFIX
 	char fn[16];
 	char *p = fn;
 	char *q = fn;
-	unsigned len;
 
 	snprintf(fn, sizeof(fn) - 3, "%s", name);
 	while(*p) {
@@ -197,18 +180,8 @@ bool AudioCodec::load(const char *name)
 		++p;
 	}
 	*q = 0;
-	len = (unsigned)strlen(fn);
-	snprintf(fn + len, sizeof(fn) - len, RLL_SUFFIX);
-	name = fn;
 
-	snprintf(path, sizeof(path), "%s/%s", Audio::getCodecPath(), name);
-#else
-#ifdef	W32
-	snprintf(path, sizeof(path), "%s/%s", Audio::getCodecPath(), name);
-#else
-	snprintf(path, sizeof(path), "%s/%s.codec", CODEC_LIBPATH, name);
-#endif
-#endif
+	snprintf(path, sizeof(path), "%s/%s%s", Audio::getCodecPath(), fn, RLL_SUFFIX);
 	return loadPlugin(path);
 }
 
