@@ -1,39 +1,21 @@
 // Copyright (C) 2005 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ccAudio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-//
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-//
-// As a special exception, you may use this file as part of a free software
-// library without restriction.  Specifically, if other files instantiate
-// templates or use macros or inline functions from this file, or you compile
-// this file and link it with other files to produce an executable, this
-// file does not by itself cause the resulting executable to be covered by
-// the GNU General Public License.  This exception does not however
-// invalidate any other reasons why the executable file might be covered by
-// the GNU General Public License.
-//
-// This exception applies only to the code released under the name GNU
-// ccAudio.  If you copy code from other releases into a copy of GNU
-// ccAudio, as the General Public License permits, the exception does
-// not apply to the code that you add in this way.  To avoid misleading
-// anyone as to the status of such modified files, you must delete
-// this exception notice from them.
-//
-// If you write modifications of your own for GNU ccAudio, it is your choice
-// whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.
+// GNU Lesser General Public License for more details.
 //
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
+
 #include "private.h"
 #include <cstdio>
 #include <cstring>
@@ -70,13 +52,12 @@ static void *map(unsigned len)
 {
 	unsigned char *pos;
 	unsigned fix = len % MAP_PAGE_FIX;
-	
+
 
 	if(fix)
 		len += MAP_PAGE_FIX - fix;
 
-	if(used + len > MAP_PAGE_SIZE)
-	{
+	if(used + len > MAP_PAGE_SIZE) {
 		page = (unsigned char *)(new void *[MAP_PAGE_COUNT]);
 		used = 0;
 	}
@@ -94,8 +75,7 @@ TelTone::tonekey_t *TelTone::find(const char *id, const char *locale)
 	char env[32];
 	char *cp, *ep;
 
-	if(locale == NULL)
-	{
+	if(locale == NULL) {
 		locale = getenv("LANG");
 		if(!locale)
 			locale="us";
@@ -112,18 +92,17 @@ TelTone::tonekey_t *TelTone::find(const char *id, const char *locale)
 	}
 
 	snprintf(namebuf, sizeof(namebuf), "%s.%s", locale, id);
-	k = key(namebuf);	
+	k = key(namebuf);
 	tk = hash[k];
 
-	while(tk)
-	{
+	while(tk) {
 		if(!stricmp(namebuf, tk->id))
 			break;
 		tk = tk->next;
 	}
 	return tk;
 }
-	
+
 
 bool TelTone::load(const char *path, const char *l)
 {
@@ -154,16 +133,14 @@ bool TelTone::load(const char *path, const char *l)
 		while(isspace(*cp))
 			++cp;
 
-		if(*cp == '[')
-		{
+		if(*cp == '[') {
 			if(loaded)
 				break;
 			strcpy(locale, buffer);
 			cp = locale;
 			lcount = 0;
 			cp = strtok(cp, "[]|\r\n");
-			while(cp)
-			{
+			while(cp) {
 				if(*cp && !l)
 					loclist[lcount++] = cp;
 				else if(*cp && !stricmp(cp, l))
@@ -192,21 +169,19 @@ bool TelTone::load(const char *path, const char *l)
 			*cp = 0;
 		cp = strtok(ep, ",");
 		count = 0;
-		while(cp)
-		{
+		while(cp) {
 			while(isspace(*cp))
 				++cp;
-						
+
 			lists[count++] = cp;
 			cp = strtok(NULL, ",");
-		}	
+		}
 		if(!count)
 			continue;
 
 		field = &lists[0];
 		first = last = again = NULL;
-		while(count--)
-		{
+		while(count--) {
 			freq = strtok(*field, " \t\r\n");
 			fdur = strtok(NULL, " \t\r\n");
 			fcount = strtok(NULL, " \t\r\n");
@@ -216,15 +191,12 @@ bool TelTone::load(const char *path, const char *l)
 
 			freq = strtok(freq, " \r\r\n");
 
-			if(isalpha(*freq))
-			{
+			if(isalpha(*freq)) {
 				tk = find(freq, loclist[0]);
-				if(tk)
-				{
+				if(tk) {
 					if(!first)
 						first = tk->first;
-					else
-					{
+					else {
 						final = tk->last;
 						again = tk->first;
 					}
@@ -243,13 +215,12 @@ bool TelTone::load(const char *path, const char *l)
 
 			def->next = NULL;
 
-			if(!fdur || !atol(fdur))
-			{
+			if(!fdur || !atol(fdur)) {
 				again = def;
 				count = 0;
 			}
 			else if((!fcount || !atoi(fcount)) && !count)
-				again = first;	
+				again = first;
 
 			cp = strtok(freq, " \t\r\n");
 			ep = cp;
@@ -262,7 +233,7 @@ bool TelTone::load(const char *path, const char *l)
 				def->f2 = 0;
 
 			if(!fcount)
-				fcount = "1";
+				fcount = (char *)"1";
 
 			def->count = atoi(fcount);
 			if(!def->count)
@@ -280,7 +251,7 @@ bool TelTone::load(const char *path, const char *l)
 				def->silence = atol(++ep);
 			else
 				def->silence = 0;
-			
+
 skip:
 			++field;
 		}
@@ -288,8 +259,7 @@ skip:
 			last->next = again;
 		field = &loclist[0];
 		i = lcount;
-		while(i--)
-		{
+		while(i--) {
 			snprintf(namebuf, sizeof(namebuf), "%s.%s",
 				*(field++), name);
 			tk = (tonekey_t *)map((unsigned)sizeof(tonekey_t) + strlen(namebuf));
