@@ -1,18 +1,20 @@
-// Copyright (C) 1999-2001 Open Source Telecom Corporation.
-//  
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
+//
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
+//
+// GNU ccAuydio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software 
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "audiotool.h"
 
@@ -30,26 +32,23 @@ void Tool::strip(char **argv)
 	unsigned long sum;
 	unsigned long count;
 	char target[PATH_MAX];
-	
+
 retry:
-	if(!*argv)
-	{
+	if(!*argv) {
 		cerr << "audiotool: -strip: missing arguments" << endl;
 		exit(-1);
 	}
 
 	fn = *argv;
 
-	if(!strcmp(fn, "--"))
-	{
+	if(!strcmp(fn, "--")) {
 		++argv;
 		goto skip;
 	}
 
 	if(!strnicmp(fn, "--", 2))
 		++fn;
-	if(!strnicmp(fn, "-framing=", 9))
-	{
+	if(!strnicmp(fn, "-framing=", 9)) {
 		framing = atoi(fn + 9);
 		++argv;
 		goto retry;
@@ -57,17 +56,15 @@ retry:
 	else if(!stricmp(fn, "-framing"))
 	{
 		++argv;
-		if(!*argv)
-		{
+		if(!*argv) {
 			cerr << "audiotool: -strip: -framing: missing argument" << endl;
 			exit(-1);
 		}
 		framing = atoi(*(argv++));
 		goto retry;
-	} 
+	}
 
-	if(!strnicmp(fn, "-silence=", 9))
-	{
+	if(!strnicmp(fn, "-silence=", 9)) {
 		silence = atoi(fn + 9);
 		++argv;
 		goto retry;
@@ -75,29 +72,25 @@ retry:
 	else if(!stricmp(fn, "-silence"))
 	{
 		++argv;
-		if(!*argv)
-		{
+		if(!*argv) {
 			cerr << "audiotool: -strip: -silence: argument missing" << endl;
 			exit(-1);
 		}
 		silence = atoi(*(argv++));
 		goto retry;
-	}		
+	}
 
 skip:
 
 	if(!framing)
 		framing = 20;
 
-	while(*argv)
-	{
-		if(!isFile(*argv))
-		{
+	while(*argv) {
+		if(!isFile(*argv)) {
 			cout << *(argv++) << ": invalid" << endl;
 			continue;
 		}
-		if(!canAccess(*argv))
-		{
+		if(!canAccess(*argv)) {
 			cout << *(argv++) << ": inaccessable" << endl;
 			continue;
 		}
@@ -107,8 +100,7 @@ skip:
 		file.getInfo(&info);
 		if(!isLinear(info.encoding))
 			codec = AudioCodec::getCodec(info, false);
-		if(!isLinear(info.encoding) && !codec)
-		{
+		if(!isLinear(info.encoding) && !codec) {
 			cout << *(argv++) << ": cannot load codec" << endl;
 			continue;
 		}
@@ -121,8 +113,7 @@ skip:
 
 		// compute silence value
 
-		while(!silence)
-		{
+		while(!silence) {
 			rtn = file.getBuffer(buffer, info.framesize);
 			if(rtn < (int)info.framesize)
 				break;
@@ -142,10 +133,9 @@ skip:
 
 		file.setPosition(0);
 
-		
+
 		tmp.create(target, &info);
-		if(!tmp.isOpen())
-		{
+		if(!tmp.isOpen()) {
 			cout << *(argv++) << ": cannot rewrite" << endl;
 			continue;
 		}
@@ -156,10 +146,8 @@ skip:
 			if(rtn < (int)info.framesize)
 				break;
 			++count;
-			if(codec)
-			{
-				if(codec->isSilent(silence, buffer, info.framecount))
-				{
+			if(codec) {
+				if(codec->isSilent(silence, buffer, info.framecount)) {
 					if(codec->getPeak(buffer, info.framecount) >= silence)
 						tmp.putBuffer(buffer, info.framesize);
 				}
@@ -173,8 +161,7 @@ skip:
 				max = current;
 
 			sum += getImpulse(info, buffer, info.framecount);
-			if(getImpulse(info, buffer, info.framecount) < silence)
-			{
+			if(getImpulse(info, buffer, info.framecount) < silence) {
 				if(getPeak(info, buffer, info.framecount) >= silence)
 					tmp.putBuffer(buffer, info.framecount);
 			}
@@ -189,7 +176,7 @@ skip:
 
 		codec = NULL;
 		buffer = NULL;
-		
+
 		file.close();
 		tmp.close();
 
