@@ -1,18 +1,19 @@
-// Copyright (C) 2005 David Sugar, Tycho Softworks
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// This file is part of GNU ccAudio2.
+//
+// GNU ccAudio2 is free software: you can redistribute it and/or modify
+// it under the terms of the GNU Lesser General Public License as published 
+// by the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// This program is distributed in the hope that it will be useful,
+// GNU ccAudio2 is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+// You should have received a copy of the GNU Lesser General Public License
+// along with GNU ccAudio2.  If not, see <http://www.gnu.org/licenses/>.
 
 #include "private.h"
 #ifdef	W32
@@ -56,5 +57,5 @@ public:
 extern class Tool tool;
 
 inline void setDelete(const char *delname)
-	{delfile = delname;};
+	{delfile = delname;}
 
